@@ -1,5 +1,5 @@
 #' @name gl.drop.ind
-#' @title Removes specified individuals from a genlight \{adegenet\} object
+#' @title Removes specified individuals from a genlight object
 #' @description
 #' The script, having deleted individuals, optionally identifies resultant
 #' monomorphic loci or loci with all values missing and deletes them
@@ -8,6 +8,8 @@
 #'
 #' The script returns a genlight object with the individuals deleted and,
 #' optionally, the recalculated locus metadata.
+#' 
+#' #' See more about data manipulation in the [tutorial](http://georges.biomatix.org/storage/app/media/uploaded-files/tutorial4dartrdatamanipulation22-dec-21-3.pdf).
 #'
 #' @param x Name of the genlight object containing SNP genotypes [required].
 #' @param ind.list A list of individuals to be removed [required].
@@ -46,7 +48,7 @@ gl.drop.ind <- function(x,
     # FLAG SCRIPT START
     funname <- match.call()[[1]]
     utils.flag.start(func = funname,
-                     build = "Josh",
+                     build = "v.2023.1",
                      verbosity = verbose)
     
     # CHECK DATATYPE
