@@ -19,10 +19,11 @@
 #' If a pair of DNA sequences are of differing length, the longer is truncated.
 #'
 #' The algorithm is that of Johann de Jong
-#' \url{https://johanndejong.wordpress.com/2015/10/02/faster-hamming-distance-in-r-2/}
+#'\url{https://johanndejong.wordpress.com/2015/10/02/faster-hamming-distance-in-r-2/}
 #' as implemented in \code{\link{utils.hamming}}.
 #'
-#' Only one of two loci are retained if their Hamming distance is less that a specified
+#' Only one of two loci are retained if their Hamming distance is less that a 
+#' specified
 #' percentage. 5 base differences out of 100 bases is a 20% Hamming distance.
 #'
 #' @param x Name of the genlight object containing the SNP data [required].
@@ -49,9 +50,9 @@
 #'
 #' @examples
 #' # SNP data
-#'   result <- gl.filter.hamming(testset.gl, threshold=0.25, verbose=3)
-#'
-#' @seealso \code{\link{gl.filter.hamming}}
+#' test <- platypus.gl
+#' test <- gl.subsample.loci(platypus.gl,n=50)
+#' result <- gl.filter.hamming(test, threshold=0.25, verbose=3)
 #'
 #' @family filters functions
 #' @import patchwork
@@ -87,7 +88,8 @@ gl.filter.hamming <- function(x,
     if (threshold < 0 || threshold > 1) {
         cat(
             warn(
-                "  Warning: Parameter 'threshold' must be an integer between 0 and 1, set to 0.2\n"
+                "  Warning: Parameter 'threshold' must be an integer between 0 
+                and 1, set to 0.2\n"
             )
         )
         threshold <- 0.2
@@ -109,12 +111,14 @@ gl.filter.hamming <- function(x,
     if (verbose >= 3) {
         cat(
             report(
-                "  Note: Hamming distance ranges from zero (sequence identity) to 1 (no bases shared at any position)\n"
+                "  Note: Hamming distance ranges from zero (sequence identity)
+                to 1 (no bases shared at any position)\n"
             )
         )
         cat(
             report(
-                "  Note: Calculating pairwise Hamming distances between trimmed reference sequence tags\n"
+                "  Note: Calculating pairwise Hamming distances between trimmed 
+                reference sequence tags\n"
             )
         )
     }
@@ -169,10 +173,8 @@ gl.filter.hamming <- function(x,
     }
     d <- d[!is.na(d)]
     
-    x <- x[, (index)]
-    
-    # That pesky genlight bug
-    x@other$loc.metrics <- x@other$loc.metrics[(index), ]
+      x2 <- x[, (index)]
+      x2@other$loc.metrics <- x@other$loc.metrics[(index), ]
     
     # PLOT HISTOGRAMS, BEFORE AFTER
     if (plot.out) {
@@ -198,10 +200,13 @@ gl.filter.hamming <- function(x,
             ylab("Count") + 
             plot_theme
         
-        # if (datatype=='SilicoDArT'){ rdepth <- x2@other$loc.metrics$AvgReadDepth } else if (datatype=='SNP'){ rdepth <-
+        # if (datatype=='SilicoDArT'){ rdepth <-
+        #x2@other$loc.metrics$AvgReadDepth } else if 
+        #(datatype=='SNP'){ rdepth <-
         # x2@other$loc.metrics$rdepth }
         plotvar <- d[d >= threshold]
-        # min <- min(plotvar,threshold) min <- trunc(min*100)/100 max <- max(plotvar,threshold,na.rm=TRUE) max <- ceiling(max*10)/10
+        # min <- min(plotvar,threshold) min <- trunc(min*100)/100 max <- 
+        #max(plotvar,threshold,na.rm=TRUE) max <- ceiling(max*10)/10
         if (datatype == "SNP") {
             xlabel <- "Post-filter SNP Hamming Distance"
         } else {
@@ -233,11 +238,11 @@ gl.filter.hamming <- function(x,
             round(threshold * taglength, 0),
             "bp\n"
         ))
-        cat(paste("    Loci deleted", (n0 - nLoc(x)), "\n"))
-        cat(paste("    Final No. of loci:", nLoc(x), "\n"))
-        cat(paste("    No. of individuals:", nInd(x), "\n"))
+        cat(paste("    Loci deleted", (n0 - nLoc(x2)), "\n"))
+        cat(paste("    Final No. of loci:", nLoc(x2), "\n"))
+        cat(paste("    No. of individuals:", nInd(x2), "\n"))
         cat(paste("    No. of populations: ", length(levels(
-            factor(pop(x))
+            factor(pop(x2))
         )), "\n"))
     }
     
@@ -256,15 +261,16 @@ gl.filter.hamming <- function(x,
             cat(report("  Saving ggplot(s) to the session tempfile\n"))
             cat(
                 report(
-                    "  NOTE: Retrieve output files from tempdir using gl.list.reports() and gl.print.reports()\n"
+                    "  NOTE: Retrieve output files from tempdir using 
+                    gl.list.reports() and gl.print.reports()\n"
                 )
             )
         }
     }
     
     # ADD TO HISTORY
-    nh <- length(x@other$history)
-    x@other$history[[nh + 1]] <- match.call()
+    nh <- length(x2@other$history)
+    x2@other$history[[nh + 1]] <- match.call()
     
     # FLAG SCRIPT END
     if (verbose > 0) {
@@ -273,5 +279,5 @@ gl.filter.hamming <- function(x,
     
     # RETURN
     
-    return(x)
+    return(x2)
 }
