@@ -6,14 +6,17 @@
 #' proportions based on observed frequencies of reference homozygotes,
 #'  heterozygotes and alternate homozygotes.
 #'
-#' Loci are filtered out if they show HWE departure in any one population.
+#' Loci are filtered out if they show HWE departure either in any one population 
+#' (n.pop.threshold =1) or in at least X number of populations 
+#' (n.pop.threshold > 1).
 #'
 #' @param x Name of the genlight object containing the SNP data [required].
 #' @param subset Way to group individuals to perform H-W tests. Either a vector
 #' with population names, 'each', 'all' (see details) [default 'each'].
 #' @param n.pop.threshold The minimum number of populations where the same locus 
-#' has to be out  of hwe to be removed [default 1]
-#' @param method_sig Method for determining statistical significance: 'ChiSquare'
+#' has to be out of H-W proportions to be removed [default 1].
+#' @param method_sig Method for determining statistical significance: 
+#' 'ChiSquare'
 #' or 'Exact' [default 'Exact'].
 #' @param multi_comp Whether to adjust p-values for multiple comparisons
 #' [default FALSE].
@@ -46,7 +49,8 @@
 #' \itemize{
 #' \item Merging all populations in the dataset using subset = 'all'.
 #' \item Within each population separately using: subset = 'each'.
-#' \item Within selected populations using for example: subset = c('pop1','pop2').
+#' \item Within selected populations using for example: subset = 
+#' c('pop1','pop2').
 #' }
 #'
 #' Two different statistical methods to test for deviations from Hardy Weinberg
@@ -80,10 +84,13 @@
 #' Correction for multiple tests can be applied using the following methods
 #' based on the function \code{\link[stats]{p.adjust}}:
 #' \itemize{
-#' \item 'holm' is also known as the sequential Bonferroni technique (Rice, 1989).
-#' This method has a greater statistical power than the standard Bonferroni test,
+#' \item 'holm' is also known as the sequential Bonferroni technique 
+#' (Rice, 1989).
+#' This method has a greater statistical power than the standard Bonferroni 
+#' test,
 #' however this method becomes very stringent when many tests are performed and
-#' many real deviations from the null hypothesis can go undetected (Waples, 2015).
+#' many real deviations from the null hypothesis can go undetected 
+#' (Waples, 2015).
 #' \item 'hochberg' based on Hochberg, 1988.
 #' \item 'hommel' based on Hommel, 1988. This method is more powerful than
 #' Hochberg's, but the difference is usually small.
@@ -103,8 +110,10 @@
 #' The number of tests on which the adjustment for multiple comparisons is
 #' the number of populations times the number of loci.
 #' 
-#' \bold{From v2.1} \code{gl.filter.hwe} takes the argument \code{n.pop.threshold}.
-#' if \code{n.pop.threshold > 1} loci will be removed only if they are concurrently 
+#' \bold{From v2.1} \code{gl.filter.hwe} takes the argument
+#'  \code{n.pop.threshold}.
+#' if \code{n.pop.threshold > 1} loci will be removed only if they are 
+#' concurrently 
 #' significant (after adjustment if applied) out of hwe in >= 
 #' \code{n.pop.threshold > 1}.
 #'
@@ -122,9 +131,11 @@
 #' \item Graffelman, J. (2015). Exploring Diallelic Genetic Markers: The Hardy
 #' Weinberg Package. Journal of Statistical Software 64:1-23.
 #' \item Graffelman, J. & Morales-Camarena, J. (2008). Graphical tests for
-#' Hardy-Weinberg equilibrium based on the ternary plot. Human Heredity 65:77-84.
+#' Hardy-Weinberg equilibrium based on the ternary plot. Human Heredity 
+#' 65:77-84.
 #' \item Graffelman, J., & Moreno, V. (2013). The mid p-value in exact tests for
-#' Hardy-Weinberg equilibrium. Statistical applications in genetics and molecular
+#' Hardy-Weinberg equilibrium. Statistical applications in genetics and
+#'  molecular
 #' biology, 12(4), 433-448.
 #' \item Hochberg, Y. (1988). A sharper Bonferroni procedure for multiple tests
 #'  of significance. Biometrika, 75, 800–803.
@@ -140,7 +151,7 @@
 #' }
 #' @seealso \code{\link{gl.report.hwe}}
 #' @rawNamespace import(data.table, except = c(melt,dcast))
-#' @family filters/filter reports
+#' @family filter functions
 #' @export
 
 gl.filter.hwe <- function(x,
@@ -169,18 +180,20 @@ gl.filter.hwe <- function(x,
     # FUNCTION SPECIFIC ERROR CHECKING check if packages are installed
     pkg <- "HardyWeinberg"
     if (!(requireNamespace(pkg, quietly = TRUE))) {
-        stop(error(
-            "Package",
-            pkg,
-            " needed for this function to work. Please install it."
-        ))
+      cat(error(
+        "Package",
+        pkg,
+        " needed for this function to work. Please install it.\n"
+      ))
+      return(-1)
     }
     
     if (datatype == "SilicoDArT") {
         cat(error("  Detected Presence/Absence (SilicoDArT) data\n"))
         stop(
             error(
-                "Cannot calculate HWE from fragment presence/absence data. Please provide a SNP dataset.\n"
+                "Cannot calculate HWE from fragment presence/absence data. 
+                Please provide a SNP dataset.\n"
             )
         )
     }
@@ -188,7 +201,8 @@ gl.filter.hwe <- function(x,
     if (alpha_val < 0 | alpha_val > 1) {
         cat(
             warn(
-                "    Warning: level of significance per locus alpha must be an integer between 0 and 1, set to 0.05\n"
+                "    Warning: level of significance per locus alpha must be an 
+                integer between 0 and 1, set to 0.05\n"
             )
         )
         alpha_val <- 0.05
@@ -208,7 +222,8 @@ gl.filter.hwe <- function(x,
         if (verbose >= 3) {
             cat(
                 warn(
-                    "  Warning: Significance of tests may indicate heterogeneity among populations\n\n"
+                    "  Warning: Significance of tests may indicate heterogeneity
+                    among populations\n\n"
                 )
             )
         }
@@ -233,7 +248,8 @@ gl.filter.hwe <- function(x,
         if (pops_hwe == 0) {
             stop(
                 error(
-                    "Fatal Error: subset parameter must be \"each\", \"all\", or a list of populations existing in the dataset\n"
+                    "Fatal Error: subset parameter must be \"each\", \"all\", or
+                    a list of populations existing in the dataset\n"
                 )
             )
         }
@@ -254,7 +270,8 @@ gl.filter.hwe <- function(x,
         if (verbose >= 3) {
             cat(
                 warn(
-                    "  Warning: Significance of tests may indicate heterogeneity among populations\n\n"
+                    "  Warning: Significance of tests may indicate heterogeneity
+                    among populations\n\n"
                 )
             )
         }
@@ -312,7 +329,8 @@ gl.filter.hwe <- function(x,
     if (length(poplist) < 1) {
         stop(
             error(
-                "No populations left after removing populations with low sample size and populations with monomorphic loci"
+                "No populations left after removing populations with low sample
+                size and populations with monomorphic loci"
             )
         )
     }
@@ -424,23 +442,25 @@ gl.filter.hwe <- function(x,
     }
     
     index <- !locNames(hold) %in% failed.loci
-    hold <- hold[, index]
-    hold@other$loc.metrics <- hold@other$loc.metrics[index, ]
+
+      hold2 <- hold[, index]
+      hold2@other$loc.metrics <- hold@other$loc.metrics[index, ]
     
     #### Report the results
     if (verbose >= 2) {
-        if (multi_comp == T) {
+        if (multi_comp == TRUE) {
             cat(
                 "  Deleted",
                 length(failed.loci),
-                "loci with significant departure from HWE, after correction for multiple tests using the",
+                "loci with significant departure from HWE, after correction for
+                multiple tests using the",
                 multi_comp_method,
                 "method at experiment-wide alpha =",
                 alpha_val,
                 "\n"
             )
         }
-        if (multi_comp == F) {
+        if (multi_comp == FALSE) {
             cat(
                 "  Deleted",
                 length(failed.loci),
@@ -449,17 +469,18 @@ gl.filter.hwe <- function(x,
                 "applied locus by locus\n"
             )
         }
-        cat("  Loci retained:", nLoc(hold), "\n\n")
+        cat("  Loci retained:", nLoc(hold2), "\n\n")
         cat(
             important(
-                "    Adjustment of p-values for multiple comparisons vary with sample size\n"
+                "    Adjustment of p-values for multiple comparisons vary with 
+                sample size\n"
             )
         )
     }
     
     # ADD TO HISTORY
-    nh <- length(hold@other$history)
-    hold@other$history[[nh + 1]] <- match.call()
+    nh <- length(hold2@other$history)
+    hold2@other$history[[nh + 1]] <- match.call()
     
     # FLAG SCRIPT END
     if (verbose >= 1) {
@@ -467,6 +488,6 @@ gl.filter.hwe <- function(x,
     }
     
     # RETURN
-    invisible(hold)
+    invisible(hold2)
     
 }
