@@ -11,6 +11,8 @@
 #'
 #' The script returns a genlight object with the new population assignments and
 #' the recalculated locus metadata.
+#' 
+#' #' See more about data manipulation in the [tutorial](http://georges.biomatix.org/storage/app/media/uploaded-files/tutorial4dartrdatamanipulation22-dec-21-3.pdf).
 #'
 #' @param x Name of the genlight object containing the SNP or presence/absence
 #'  (SilicoDArT) data [required].
@@ -51,7 +53,7 @@ gl.keep.pop <-  function(x,
     # FLAG SCRIPT START
     funname <- match.call()[[1]]
     utils.flag.start(func = funname,
-                     build = "Jody",
+                     build = "v.2023.1",
                      verbosity = verbose)
     
     # CHECK DATATYPE
