@@ -58,7 +58,10 @@
 #'   chromosome IDs" in the following link:
 #'   https://www.cog-genomics.org/plink/1.9/input
 #'   
-#' @return NULL
+#'  Note that the function might not work if there are spaces in the path to the
+#'   plink executable.
+#'   
+#' @return  returns no value (i.e. NULL)
 #' @references
 #' Purcell, Shaun, et al. 'PLINK: a tool set for whole-genome association and
 #' population-based linkage analyses.' The American journal of human genetics
@@ -105,6 +108,11 @@ gl2plink <- function(x,
     
     outfilespec <- file.path(outpath, outfile)
     
+    if(is.null(x$chromosome)){
+      x$chromosome <- as.factor(rep("1",nLoc(x)))
+      cat(warn("   Chromosome slot is empty. Using 1 as dummy name.\n"))
+    }
+    
     snp_temp <- as.data.frame(cbind(as.character(x$chromosome),x$position))
     colnames(snp_temp) <- c("chrom","snp_pos")
     
@@ -136,16 +144,15 @@ gl2plink <- function(x,
     write.table(
         gl_map,
         file = paste0(outfilespec, ".map"),
-        quote = F,
-        row.names = F,
-        col.names = F
+        quote = FALSE,
+        row.names = FALSE,
+        col.names = FALSE
     )
     
     ########## .fam (PLINK sample information file)
     
     sample.id_temp <- indNames(x)
-    sample.id_temp <-
-        gsub(" ", replacement = "_", sample.id_temp)
+    sample.id_temp <- gsub(" ", replacement = "_", sample.id_temp)
     
     # Family ID ('FID')
     FID <- as.character(x$pop)
@@ -168,8 +175,7 @@ gl2plink <- function(x,
         sex_code[nchar(sex_code) == 0] <- "0"
     }
     
-    gl_fam <-
-        cbind(FID, IID, ID_dad, ID_mom, sex_code, phen_value)
+    gl_fam <- cbind(FID, IID, ID_dad, ID_mom, sex_code, phen_value)
     
     x_mat <- as.matrix(x[, ])
     homs1 <- paste(substr(x@loc.all, 1, 1), "/", substr(x@loc.all, 1, 1), sep = "")
@@ -239,7 +245,6 @@ gl2plink <- function(x,
                 bedfile.out
             }
         
-        
         system_verbose <-function(...) {
             report <-system(..., intern = T)
             message(
